==> gbsite-1.1.1.tar.gz: gbsite/templates/master/master_newsinputpage.php <==
<table cellpadding="4" cellspacing="0" border="0" width="100%">
<tr>
<td colspan="3"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2"><p><?= $scenario ?> your news bulletin. <a href="/project/<?= $project_name ?>/news/newslist.php">Click here</a> for a list of all news bulletins available for update.</p></font></td>
</tr>
<form method="post" action="<?= $PHP_SELF ?>">
<input type="hidden" name="temp_id" value="<?= $temp_id ?>">
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Headline:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" size="50" name="headline" value="<?= $headline ?>"></td>
</tr>
<tr>
<td nowrap valign="top"><font face="<?= $font_1 ?>" size="2"><b>News Bulletin:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><textarea name="body" cols="40" rows="5" wrap><?= $body ?></textarea></td>
</tr>
<tr>
<td nowrap valign="top"><font face="<?= $font_1 ?>" size="2"><b>Display:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="checkbox" name="active" value="t" <?= $active ?>>&nbsp;<font face="<?= $font_1 ?>" size="2">Check for yes.</font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td><input type="submit" value="Submit News"></td>
</tr>
</form>
</table>

==> gbsite-2.0.0.tar.gz: gbsite/templates/master/master_newsinputpage.php <==
<table cellpadding="4" cellspacing="0" border="0" width="100%">
<tr>
<td colspan="3"><img src="<?= $image_path ?>/proj_spacer.gif" width="42" height="15"><font face="<?= $font_1 ?>" size="2" color="<?= $color_6?>"><b>The <?= $project_name ?> Project</b></font></td>
</tr>
<tr>
<td colspan="3"><font face="<?= $font_1 ?>" size="2"><p><?= $scenario ?> your news bulletin. <a href="/project/<?= $project_name ?>/news/newslist.php">Click here</a> for a list of all news bulletins available for update.</p></font></td>
</tr>
<form method="post" action="<?= $PHP_SELF ?>">
<input type="hidden" name="temp_id" value="<?= $temp_id ?>">
<tr>
<td nowrap><font face="<?= $font_1 ?>" size="2"><b>Headline:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="text" size="50" name="headline" value="<?= $headline ?>"></td>
</tr>
<tr>
<td nowrap valign="top"><font face="<?= $font_1 ?>" size="2"><b>News Bulletin:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><textarea name="body" cols="40" rows="5" wrap><?= $body ?></textarea></td>
</tr>
<tr>
<td nowrap valign="top"><font face="<?= $font_1 ?>" size="2"><b>Display:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="checkbox" name="active" value="t" <?= $active ?>>&nbsp;<font face="<?= $font_1 ?>" size="2">Check for yes. <i>(If not checked this news item will not be dispayed on your project homepage or the site homepage)</i></font></td>
</tr>
<tr>
<td nowrap valign="top"><font face="<?= $font_1 ?>" size="2"><b>Display Sitewide:</b></font></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td width="100%"><input type="checkbox" name="on_homepage" value="t" <?= $on_homepage ?>>&nbsp;<font face="<?= $font_1 ?>" size="2">Check for yes. <i>(If not checked this news item will not be dispayed on the site homepage)</i></font></td>
</tr>
<tr>
<td><img src="<?= $image_path ?>/shim.gif" width="1" height="1"></td>
<td><img src="<?= $image_path ?>/shim.gif" width="8" height="1"></td>
<td><input type="submit" value="Submit News"></td>
</tr>
</form>
</table>
